@@ -66,7 +66,7 @@ class NotebookClient(LoggingConfigurable):
             is raised.
 
             Returning ``None`` or ``-1`` will disable the timeout for the cell.
-            Not setting ``timeout_func`` will cause the preprocessor to
+            Not setting ``timeout_func`` will cause the client to
             default to using the ``timeout`` trait for all cells. The
             ``timeout_func`` trait overrides ``timeout`` if it is not ``None``.
             """
@@ -101,7 +101,8 @@ class NotebookClient(LoggingConfigurable):
             """
             If ``False`` (default), when a cell raises an error the
             execution is stopped and a `CellExecutionError`
-            is raised.
+            is raised, except if the error name is in
+            ``allow_error_names``.
             If ``True``, execution errors are ignored and the execution
             is continued until the end of the notebook. Output from
             exceptions is included in the cell output in both cases.
@@ -109,19 +110,31 @@ class NotebookClient(LoggingConfigurable):
         ),
     ).tag(config=True)
 
+    allow_error_names: t.List[str] = List(
+        Unicode(),
+        help=dedent(
+            """
+            List of error names which won't stop the execution. Use this if the
+            ``allow_errors`` option it too general and you want to allow only
+            specific kinds of errors.
+            """
+        ),
+    ).tag(config=True)
+
     force_raise_errors: bool = Bool(
         False,
         help=dedent(
             """
             If False (default), errors from executing the notebook can be
             allowed with a ``raises-exception`` tag on a single cell, or the
-            ``allow_errors`` configurable option for all cells. An allowed error
-            will be recorded in notebook output, and execution will continue.
-            If an error occurs when it is not explicitly allowed, a
-            `CellExecutionError` will be raised.
+            ``allow_errors`` or ``allow_error_names`` configurable options for
+            all cells. An allowed error will be recorded in notebook output, and
+            execution will continue. If an error occurs when it is not
+            explicitly allowed, a `CellExecutionError` will be raised.
             If True, `CellExecutionError` will be raised for any error that occurs
-            while executing the notebook. This overrides both the
-            ``allow_errors`` option and the ``raises-exception`` cell tag.
+            while executing the notebook. This overrides the ``allow_errors``
+            and ``allow_error_names`` options and the ``raises-exception`` cell
+            tag.
             """
         ),
     ).tag(config=True)
@@ -339,7 +352,12 @@ class NotebookClient(LoggingConfigurable):
             self.km = self.kernel_manager_class(config=self.config)
         else:
             self.km = self.kernel_manager_class(kernel_name=self.kernel_name, config=self.config)
-        self.km.client_class = 'jupyter_client.asynchronous.AsyncKernelClient'
+
+        # If the current kernel manager is still using the default (synchronous) KernelClient class,
+        # switch to the async version since that's what NBClient prefers.
+        if self.km.client_class == 'jupyter_client.client.KernelClient':
+            self.km.client_class = 'jupyter_client.asynchronous.AsyncKernelClient'
+
         return self.km
 
     async def _async_cleanup_kernel(self) -> None:
@@ -726,13 +744,20 @@ class NotebookClient(LoggingConfigurable):
             cell: NotebookNode,
             exec_reply: t.Optional[t.Dict]) -> None:
 
-        cell_allows_errors = self.allow_errors or "raises-exception" in cell.metadata.get(
-            "tags", []
-        )
+        if exec_reply is None:
+            return None
 
-        if self.force_raise_errors or not cell_allows_errors:
-            if (exec_reply is not None) and exec_reply['content']['status'] == 'error':
-                raise CellExecutionError.from_cell_and_msg(cell, exec_reply['content'])
+        exec_reply_content = exec_reply['content']
+        if exec_reply_content['status'] != 'error':
+            return None
+
+        cell_allows_errors = (not self.force_raise_errors) and (
+            self.allow_errors
+            or exec_reply_content.get('ename') in self.allow_error_names
+            or "raises-exception" in cell.metadata.get("tags", []))
+
+        if not cell_allows_errors:
+            raise CellExecutionError.from_cell_and_msg(cell, exec_reply_content)
 
     async def async_execute_cell(
             self,
@@ -1074,7 +1099,7 @@ def execute(
     km : AsyncKernelManager, optional
       If supplied, the specified kernel manager will be used for code execution.
     kwargs :
-      Any other options for ExecutePreprocessor, e.g. timeout, kernel_name
+      Any other options for NotebookClient, e.g. timeout, kernel_name
     """
     resources = {}
     if cwd is not None:
