@@ -20,8 +20,7 @@ from ..exceptions import CellExecutionError
 
 from traitlets import TraitError
 from nbformat import NotebookNode
-from jupyter_client.asynchronous import AsyncKernelClient
-from jupyter_client import KernelManager, MultiKernelManager
+from jupyter_client import KernelManager
 from jupyter_client.kernelspec import KernelSpecManager
 from nbconvert.filters import strip_ansi
 from testpath import modified_env
@@ -414,9 +413,8 @@ def test_startnewkernel_with_kernelmanager():
     nb = nbformat.v4.new_notebook()
     km = KernelManager()
     executor = NotebookClient(nb, km=km)
-    kc, kernel_id = executor.start_new_kernel_client()
-    # no kernel_id for a single kernel manager
-    assert kernel_id is None
+    executor.start_new_kernel()
+    kc = executor.start_new_kernel_client()
     # prove it initalized client
     assert kc is not None
     # since we are not using the setup_kernel context manager,
@@ -426,24 +424,25 @@ def test_startnewkernel_with_kernelmanager():
     kc.stop_channels()
 
 
-def test_startnewkernel_with_multikernelmanager():
+def test_start_new_kernel_history_file_setting():
     nb = nbformat.v4.new_notebook()
-    km = MultiKernelManager()
+    km = KernelManager()
     executor = NotebookClient(nb, km=km)
-    kc, kernel_id = executor.start_new_kernel_client()
-    # a multi kernel manager always gives back an id to the started kernel
-    assert kernel_id is not None
-    # prove it initalized an async client
-    assert isinstance(kc, AsyncKernelClient)
+    kc = km.client()
+
+    # Should start empty
+    assert executor.extra_arguments == []
+    # Should assign memory setting for ipykernel
+    executor.start_new_kernel()
+    assert executor.extra_arguments == ['--HistoryManager.hist_file=:memory:']
+    # Should not add a second hist_file assignment
+    executor.start_new_kernel()
+    assert executor.extra_arguments == ['--HistoryManager.hist_file=:memory:']
+
     # since we are not using the setup_kernel context manager,
     # cleanup has to be done manually
     kc.shutdown()
-    km.cleanup(kernel_id)
-    km.remove_kernel(kernel_id)
-    # check that the kernel doesn't exist anymore
-    with pytest.raises(KeyError) as e_info:
-        km.get_kernel(kernel_id)
-    assert str(e_info.value) == "'Kernel with id not found: {}'".format(kernel_id)
+    km.cleanup()
     kc.stop_channels()
 
 
@@ -550,7 +549,7 @@ while True: continue
 
         with pytest.raises(TimeoutError):
             executor.execute()
-        km = executor.start_kernel_manager()
+        km = executor.create_kernel_manager()
 
         async def is_alive():
             return False
@@ -1410,6 +1409,24 @@ class TestRunCell(NBClientTestsBase):
         # Should also consume the message stream
         assert cell_mock.outputs == []
 
+    @prepare_cell_mocks(
+        reply_msg={
+            'msg_type': 'execute_reply',
+            'header': {'msg_type': 'execute_reply'},
+            # ERROR
+            'content': {'status': 'error', 'ename': 'NotImplementedError'},
+        }
+    )
+    def test_allow_error_names(self, executor, cell_mock, message_mock):
+        executor.allow_error_names = ['NotImplementedError']
+        # Should NOT raise
+        executor.execute_cell(cell_mock, 0)
+
+        # An error followed by an idle
+        assert message_mock.call_count == 1
+        # Should also consume the message stream
+        assert cell_mock.outputs == []
+
     @prepare_cell_mocks(
         reply_msg={
             'msg_type': 'execute_reply',
